@@ -1,6 +1,6 @@
 /*
  *========================================================================
- * $Id: dieharder.h 326 2007-05-23 01:12:07Z rgb $
+ * $Id: dieharder.h 448 2008-09-07 17:58:00Z rgb $
  *
  * See copyright in copyright.h and the accompanying file COPYING
  *========================================================================
@@ -8,6 +8,9 @@
 
 #include "copyright.h"
 
+/* To enable large file support */
+#define _FILE_OFFSET_BITS 64
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -26,6 +29,12 @@
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_matrix.h>
 #include <dieharder/libdieharder.h>
+
+/*
+ * Flags to control all output formatting etc.
+ */
+#include "output.h"
+
 /*
  * user_template sources are here, not in library
  */
@@ -59,6 +68,14 @@
  */
 #define nullfree(a) {free(a);a = 0;}
 
+/*
+ * This is how one gets a macro into quotes; an important one to keep
+ * in all program templates.
+ */
+#define _QUOTEME(x) #x
+#define QUOTEME(x) _QUOTEME(x)
+
+
  /*
   *========================================================================
   * Subroutine Prototypes
@@ -87,6 +104,7 @@
  void add_my_types(void);
  void help_user_template(void);
  void list_rngs(void);
+ void list_tests(void);
  void parsecl(int argc, char **argv);
  void run_diehard_2dsphere(void);
  void run_diehard_3dsphere(void);
@@ -109,8 +127,13 @@
  void run_rgb_bitdist(void);
  void run_rgb_persist(void);
  void run_rgb_timing(void);
+ void run_rgb_minimum_distance(void);
+ void run_rgb_permutations(void);
+ void rgb_lmn(void);
+ void run_rgb_operm(void);
  void run_sts_monobit(void);
  void run_sts_runs(void);
+ void run_sts_serial(void);
  void run_user_template(void);
  void startup(void);
  void user_template(Test **test,int irun);
@@ -118,7 +141,7 @@
  void Xtest_eval(Xtest *xtest);
 
 #ifdef RDIEHARDER
- int histogram(double *input,int inum,double min,double max,int nbins,char *label);
+ int histogram(double *input, char *pvlabel, int inum, double min, double max, int nbins, char *label);
  Test *rdh_testptr;		/* kludge: need a global to report back to main + R */
  Dtest *rdh_dtestptr;	/* kludge: need a global to report back to main + R */
 #endif
@@ -142,15 +165,17 @@
  int list;              /* List all tests flag */
  int List;              /* List all generators flag */
  int ntuple;            /* n-tuple size for n-tuple tests */
- int num_randoms;		/* the number of randoms stored into memory and usable */
- int output;		/* equals 1 if you output to file, otherwise 0. */
+ int num_randoms;	/* the number of randoms stored into memory and usable */
+ int output_file;	/* equals 1 if you output to file, otherwise 0. */
  int overlap;           /* equals 1 if you really want to use diehard overlap */
  int psamples;          /* Number of test runs in final KS test */
  int quiet;             /* quiet flag -- surpresses full output report */
  int rgb;               /* rgb test number */
  int sts;               /* sts test number */
  uint Seed;             /* user selected seed.  Surpresses reseeding per sample.*/
- uint tsamples;         /* Generally should be "a lot". */
+ uint table;            /* selects "table" output mode */
+ uint tflag;            /* binary flag(s) to control what goes in the table */
+ off_t tsamples;        /* Generally should be "a lot".  off_t is u_int64_t. */
  int user;              /* user defined test number */
  int verbose;           /* Default is not to be verbose. */
  double x_user;         /* General purpose command line inputs for use */
@@ -179,6 +204,7 @@
  double *ks_pvalue,*ks_pvalue2;
  unsigned int kspi;
  struct timeval tv_start,tv_stop;
+ double rng_avg_time_nsec,rng_rands_per_second;
  int dummy,idiot;
  FILE *fp;
 #define MAXFIELDNUMBER 8
@@ -195,7 +221,11 @@
  char filename[K];      /* Input file name */
  int fromfile;		/* set true if file is used for rands */
  int filenumbits;	/* number of bits per integer */
- uint filecount;	/* number of rands in file */
+ /*
+  * If we have large files, we can have a lot of rands.  off_t is
+  * automagically set to u_int64_t if FILE_OFFSET_BITS is set to 64.
+  */
+ off_t filecount;	/* number of rands in file */
  char filetype;         /* file type */
 
  void show_test_header(Dtest *dtest,Test **test);
@@ -205,3 +235,13 @@
  void show_test_results_debut(Dtest *dtest,Test **test);
  void test_footer(Dtest *dtest, double pvalue, double *pvalues);
 
+/*
+ * List new rng types to be added in startup.c.  Use "empty" or
+ * libdieharder rng sources as template, uncomment/clone the lines that
+ * add your own type(s) in startup.c.  Consider sending "good" generators
+ * that pass all or most tests or "classic" generators good or bad that
+ * people might want to test back to me to include in libdieharder.
+ */
+ GSL_VAR const gsl_rng_type *gsl_rng_empty_random;
+ /* GSL_VAR const gsl_rng_type *gsl_rng_my_new_random; */
+
