@@ -9,7 +9,8 @@ void diehard_parking_lot(Test **test,int irun);
 
 static Dtest diehard_parking_lot_dtest = {
   "Diehard Parking Lot Test",
-  "\n\
+  "diehard_parking_lot",
+  "\
 #==================================================================\n\
 #             Diehard Parking Lot Test (modified).\n\
 # This tests the distribution of attempts to randomly park a\n\
